package com.huashe.park.core.service;

import com.huashe.park.domain.entity.ProjectCoordinateInfo;

import java.util.List;

/**
 * 工程坐标配置Service接口
 * 
 * @author ruoyi
 * @date 2025-02-14
 */
public interface IProjectCoordinateInfoService 
{
    /**
     * 查询工程坐标配置
     * 
     * @param id 工程坐标配置主键
     * @return 工程坐标配置
     */
    public ProjectCoordinateInfo selectProjectCoordinateInfoById(Long id);

    /**
     * 查询工程坐标配置列表
     * 
     * @param projectCoordinateInfo 工程坐标配置
     * @return 工程坐标配置集合
     */
    public List<ProjectCoordinateInfo> selectProjectCoordinateInfoList(ProjectCoordinateInfo projectCoordinateInfo);

    /**
     * 新增工程坐标配置
     * 
     * @param projectCoordinateInfo 工程坐标配置
     * @return 结果
     */
    public int insertProjectCoordinateInfo(ProjectCoordinateInfo projectCoordinateInfo);

    /**
     * 修改工程坐标配置
     * 
     * @param projectCoordinateInfo 工程坐标配置
     * @return 结果
     */
    public int updateProjectCoordinateInfo(ProjectCoordinateInfo projectCoordinateInfo);

    /**
     * 批量删除工程坐标配置
     * 
     * @param ids 需要删除的工程坐标配置主键集合
     * @return 结果
     */
    public int deleteProjectCoordinateInfoByIds(Long[] ids);

    /**
     * 删除工程坐标配置信息
     * 
     * @param id 工程坐标配置主键
     * @return 结果
     */
    public int deleteProjectCoordinateInfoById(Long id);
}
